==> yubikey-manager-3.1.0.tar.gz: yubikey-manager-3.1.0/setup.py <==
# Copyright (c) 2015 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import sys
import os
from setuptools import setup

install_requires = [
    'six', 'pyscard', 'pyusb', 'click', 'cryptography', 'pyopenssl', 'fido2 >= 0.7'
]
tests_require = []
if sys.version_info < (3, 3):
    tests_require.append('mock')
if sys.version_info < (3, 4):
    install_requires.append('enum34')
if sys.platform == 'win32':
    install_requires.append('pypiwin32')

with open(
    os.path.join(
        os.path.dirname(__file__), 'ykman/VERSION')) as version_file:
    version = version_file.read().strip()

setup(
    name='yubikey-manager',
    version=version,
    author='Dain Nilsson',
    author_email='dain@yubico.com',
    maintainer='Yubico Open Source Maintainers',
    maintainer_email='ossmaint@yubico.com',
    url='https://github.com/Yubico/yubikey-manager',
    description='Tool for managing your YubiKey configuration.',
    license='BSD 2 clause',
    entry_points={
        'console_scripts': ['ykman=ykman.cli.__main__:main'],
    },
    packages=[
        'ykman', 'ykman.native', 'ykman.scancodes', 'ykman.cli'],
    install_requires=install_requires,
    package_data={'ykman': ['VERSION']},
    include_package_data=True,
    test_suite='test',
    tests_require=tests_require,
    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Development Status :: 5 - Production/Stable',
        'Environment :: X11 Applications :: Qt',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Security :: Cryptography',
        'Topic :: Utilities'
    ]
)

==> yubikey-manager-3.1.2.tar.gz: yubikey-manager-3.1.2/setup.py <==
# Copyright (c) 2015 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import sys
import os
from setuptools import setup

install_requires = [
    'six', 'pyscard', 'pyusb', 'click',
    'cryptography', 'pyopenssl', 'fido2 >= 0.7, < 0.9'
]
tests_require = []
if sys.version_info < (3, 3):
    tests_require.append('mock')
if sys.version_info < (3, 4):
    install_requires.append('enum34')
if sys.platform == 'win32':
    install_requires.append('pypiwin32')

with open(
    os.path.join(
        os.path.dirname(__file__), 'ykman/VERSION')) as version_file:
    version = version_file.read().strip()

setup(
    name='yubikey-manager',
    version=version,
    author='Dain Nilsson',
    author_email='dain@yubico.com',
    maintainer='Yubico Open Source Maintainers',
    maintainer_email='ossmaint@yubico.com',
    url='https://github.com/Yubico/yubikey-manager',
    description='Tool for managing your YubiKey configuration.',
    license='BSD 2 clause',
    entry_points={
        'console_scripts': ['ykman=ykman.cli.__main__:main'],
    },
    packages=[
        'ykman', 'ykman.native', 'ykman.scancodes', 'ykman.cli'],
    install_requires=install_requires,
    package_data={'ykman': ['VERSION']},
    include_package_data=True,
    test_suite='test',
    tests_require=tests_require,
    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Development Status :: 5 - Production/Stable',
        'Environment :: X11 Applications :: Qt',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Security :: Cryptography',
        'Topic :: Utilities'
    ]
)
